:warning:  **Package under developing**: Can be subjected to any critic change!

# OpenVariant
![PyPI](https://img.shields.io/pypi/v/open-variant)

## Install

```bash
pip install open-variant
```

Check [examples](./examples) for any kind of interest on how to use this package.  
